NetworkAddress

Enum NetworkAddress 

pub enum NetworkAddress {
    Clear(SocketAddr),
    Tor(OnionAddr),
}
A network address which can be encoded into the format required to send to other Monero peers.

Variants

Implementations

Source

impl NetworkAddress

pub const fn get_zone(&self) -> NetZone

pub const fn is_loopback(&self) -> bool

pub const fn is_local(&self) -> bool

pub const fn port(&self) -> u16