pub enum NetworkAddress {
Clear(SocketAddr),
Tor(OnionAddr),
}Expand description
A network address which can be encoded into the format required to send to other Monero peers.
Variants
Clear(SocketAddr)
Tor(OnionAddr)
Implementations